<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once('../wp-includes/compat.php');
require_once('../wp-includes/functions.php');
require_once('../wp-includes/classes.php');

if (!file_exists('../wp-config-sample.php'))
	wp_die('Hampura, kuring merlukeun berkas wp-config-sample.php pikeun migawé. Mangga muat ulang ieu berkas tina instalasi WordPress anjeun.');

$configFile = file('../wp-config-sample.php');

if ( !is_writable('../'))
	wp_die("Hampura, kuring teu bisa nulis kana éta diréktori. Anjeun kudu ngarobah wewenang diréktori WordPress anjeun atawa nyiptakeun berkas wp-config.php anjeun sacara manual.");

// Check if wp-config.php has been created
if (file_exists('../wp-config.php'))
	wp_die("<p>Berkas 'wp-config.php' geus nyampak. Mun anjeun perlu nyetél ulang item-item ropéaan dina ieu berkas, mangga pupus heula. Anjeun bisa nyobaan <a href='install.php'>instalkeun ayeuna</a>.</p>");

// Check if wp-config.php exists above the root directory
if (file_exists('../../wp-config.php') && ! file_exists('../../wp-load.php'))
	wp_die("<p>Berkas 'wp-config.php' geus nyampak satingkat saluhureun instalasi WordPress anjeun. Mun anjeun perlu nyetél ulang item-item ropéaan dina ieu berkas, mangga pupus heula. Anjeun bisa nyobaan <a href='install.php'>instalkeun ayeuna</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; Sétel Berkas Ropéaan</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Wilujeng sumping ka WordPress. Saméméh ngamimitian, kuring merlukeun sawatara inpormasi dina databés. Anjeun kudu apal kana item-item di handap ieu saméméh neruskeun.</p>
<ol>
	<li>Ngaran databés</li>
	<li>Sandiasma databés</li>
	<li>Sandikecap databés</li>
	<li>Hosta databés</li>
	<li>Prépiksu tabél (mun anjeun boga maksud ngajalankeun WordPress leuwih ti hiji dina hiji databés) </li>
</ol>
<p><strong>Mun lantaran sawatara alasan nyiptakeun ieu berkas sacara otomatis teu lumaku, ulah salempang. Nu dilakukeun dina ieu prosés ukur ngeusikeun inpormasi dina databés kana berkas ropéaan. Anjeun ogé bisa langsung muka <code>wp-config-sample.php</code> dina pangropéa téksu, eusikeun inpormasi anjeun, laju teundeun jadi <code>wp-config.php</code>.</strong></p>
<p>Lumrahna, ieu item-item dibikeun ku ISP anjeun ka anjeun. Mun anjeun teu mibanda ieu inpormasi, anjeun perlu ngahubungan éta ISP saméméh anjeun bisa neruskeun. Mun anjeun geus siap&hellip;</p>

<p class="step"><a href="setup-config.php?step=1" class="button">Hayu lah!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Di handap ieu anjeun kudu ngasupkeun inpormasi sambungan databés abjeun. Mun anjeun teu surti ngeunaan éta inpormasi, hubungan hosta anjeun.</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Ngaran Databés</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>Ngaran databés tempat anjeun rék ngajalankeun WP. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Sandiasma</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Sandiasma MySQL anjeun</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Sandikecap</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...sarta sandikecap MySQL.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Hosta Databés</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>99% kasempetan keur anjeun geusan teu perlu ngarobah ieu niléy.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Table Prefix</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Mun anjeun boga maksud ngajalankeun instalan WordPress leuwih ti hiji dina hiji databés, robah nu ieu.</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="Submit" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen('../wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod('../wp-config.php', 0666);

	display_header();
?>
<p>Hadé lah! Anjeun geus hasil ngaliwatan ieu bagian instalasi. Kiwari WordPress bisa sambungkecap jeung databés anjeun. Mun anjeun geus siap, kiwari waktuna pikeun&hellip;</p>

<p class="step"><a href="install.php" class="button">Jalankeun Instalan</a></p>
<?php
	break;
}
?>
</body>
</html>
